@@ -1,18 +1,15 @@
 #!/bin/sh
 
-AUTOCONF=autoconf
-AUTOMAKE=automake
-ACLOCAL=aclocal
-AUTOHEADER=autoheader
-LIBTOOLIZE=libtoolize
+AUTOCONF=autoconf259
+AUTOMAKE=automake19
+ACLOCAL=aclocal19
+AUTOHEADER=autoheader259
+LIBTOOLIZE=libtoolize15
 
 # host os check 
-if [ ! -f /etc/fedora-release ]; then
-   echo "running host is not Fedora Core";
-   exit 1;
-fi
-if [ x"`cat /etc/fedora-release`" != x"Fedora Core release 1 (Yarrow)" ]; then
-   echo "running host is not Frdora Core release 1"; 
+UNAME=`uname -s`
+if test X"$UNAME" != X"FreeBSD" ; then
+   echo "running host is not FreeBSD";
    exit 1;
 fi
 
