@@ -2,7 +2,12 @@
 
 XMLLINT=xmllint
 TOOLSDIR=`dirname $0`
-SGML_CATALOG_FILES=$TOOLSDIR/../docbook/xml/4.2/catalog.xml
+CURDIR=`pwd`
+cd $TOOLSDIR/..
+BASEDIR=`pwd`
+cd $CURDIR
+
+SGML_CATALOG_FILES=$BASEDIR/docbook/xml/4.4/catalog.xml
 export SGML_CATALOG_FILES
 
 which $XMLLINT > /dev/null
@@ -12,5 +17,5 @@ if [ $RETVAL -ne 0 ]; then
   exit 1;
 fi
 
-$XMLLINT --noout --valid --catalogs $*
+$XMLLINT --xinclude --noout --postvalid --nonet --catalogs $*
 exit $?
