@@ -25,7 +25,7 @@
  * THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-/* $Id: SL_Object.cpp,v 1.11 2005/03/25 05:28:05 orrisroot Exp $ */
+/* $Id: SL_Object.cpp,v 1.12 2005/10/27 04:18:57 orrisroot Exp $ */
 #define  LIBSATELLITE_EXPORTS
 
 #ifdef HAVE_CONFIG_H
@@ -489,7 +489,6 @@ void SL_Object::Read(){
   char str[ONELINE],*p=str;
   double buf[ONELINE];
   int dim = 1;
-  Base_Buffer *bufp=0;
   Index idx;
   memset(str,0,ONELINE*sizeof(char));
   if(objtype == SL_OBJ::SERIES_O || objtype == SL_OBJ::SNAPSHOT_O ||
@@ -538,6 +537,8 @@ void SL_Object::Read(){
     buffer->InitBuffer();
     ((Scalar_Buffer *)buffer)->SetScalar(buf[0]);
     break;
+  default: /* nothing */
+    break;
   }
 }
 
@@ -685,12 +686,13 @@ int SL_Object::formatting(char *fmt, size_t index_width, int win_c){
 // scalar opecode
 SL_Object *SL_Object::scalar_op(int dptr_n, SL_Object *obj){
   static char *where="(scalar opration)";
-  SL_Object   *ret_obj;
+  SL_Object   *ret_obj = 0;
   Base_Buffer *ret_buf,*src_buf;
   double *d, *dst;
   int i,size;
   SL_OBJ::TYPE type;
   OPEFUNC dptr = operators[dptr_n];
+  ret_buf = src_buf = 0;
 
   // error check
   d=(double*)buffer->GetDataPointer();
@@ -744,7 +746,7 @@ SL_Object *SL_Object::scalar_op(int dptr_n, SL_Object *obj){
 // operation of series
 SL_Object *SL_Object::series_op(int dptr_n, SL_Object *obj){
   static char *where="(series opration)";
-  SL_Object *ret_obj;
+  SL_Object *ret_obj = 0;
   Base_Buffer *ret_buf=0,*buffer2=0;
   int    i,j,t,time=0,size=0, dimx, dimy;;
   bool   is_single, is_scalar, is_series;
@@ -864,9 +866,10 @@ SL_Object *SL_Object::string_op(int dptr_n, SL_Object *obj){
   static char *where = "(string operation)";
   SL_Object *ret_obj;
   Base_Buffer *ret_buf,*src_buf,*dst_buf;
+  ret_buf = src_buf = dst_buf = NULL;
   int  a_word;
   SL_OBJ::TYPE ret_type,src_type;
-  SOPEFUNC method;
+  SOPEFUNC method  = (SOPEFUNC)NULL;
   /* search for method */
   switch(dptr_n){
   case MATH_ADD: method = string_add; break;
@@ -875,7 +878,7 @@ SL_Object *SL_Object::string_op(int dptr_n, SL_Object *obj){
   case MATH_DIV: method = string_div; break;
   case MATH_EQ:  method = string_eq;  break;
   case MATH_NE:  method = string_ne;  break;
-  default: 
+  default:
     syscom->console->execerror("not supported method",where);
     break;
   }
@@ -1009,6 +1012,9 @@ static Base_Buffer *getstring(Base_Buffer *src, SL_OBJ::TYPE type){
         }
       }
       break;
+    default:
+      /* nothing */
+      break;
     }
   }catch(buffer_exception err){
     delete ret;
