@@ -1,6 +1,5 @@
 /* 
- * Copyright (c) 2003 RIKEN (The Institute of Physical and Chemical Research)
- * All rights reserved.
+ * Copyright (c) 2003-2005 RIKEN Japan, All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -26,7 +25,7 @@
  * THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-/* $Id: SystemCommon.cpp,v 1.5 2004/12/17 15:56:48 orrisroot Exp $ */
+/* $Id: SystemCommon.cpp,v 1.7 2005/10/29 09:21:04 orrisroot Exp $ */
 #define  LIBSATELLITE_EXPORTS
 
 #ifdef HAVE_CONFIG_H
@@ -315,7 +314,7 @@ void SystemCommon::SCReturnScalar(double sc){
   }
 }
 
-void SystemCommon::SCReturnString(char *str){
+void SystemCommon::SCReturnString(const char *str){
   String_Buffer *buf=0;
   Index idx;
   if(ret!=0){
@@ -340,6 +339,72 @@ void SystemCommon::SCReturnString(char *str){
   }
 }
 
+void SystemCommon::sl4_syscom_return_string(int dim, int *idx, 
+                                            sl4_list_t *lst){
+  int i;
+  sl4_list_iterator_t it;
+  sl4_string_t *str;
+  const char *cstr;
+  String_Buffer *buf=0;
+  Index ptr;
+  if(ret!=0){
+    delete ret;
+  }
+  buf = new String_Buffer;
+  buf->SetDim(dim);
+  try{
+    for(i = 0; i < dim; i++)
+      buf->SetIndex(i,idx[i]);
+    buf->InitBuffer();
+    ret = new SL_Object(SL_OBJ::STRING_O,buf);
+    if(sl4_list_size(lst) == (unsigned int)buf->IndexSize()) {
+      sl4_list_begin(lst, &it);
+      for(i = 0; i < buf->IndexSize(); i++){
+        ptr = buf->rIndex(i);
+        str = (sl4_string_t*)sl4_list_it_data(&it);
+        cstr = sl4_string_get_cstr(str);
+        ((String_Buffer *)ret->GetBufferPointer())->SetString(ptr, cstr);
+        sl4_list_it_next(&it);
+      }
+    }
+  }catch(execerr_exception){
+    delete buf;
+    ret=0;
+    throw;
+  }catch(bad_alloc){
+    delete buf;
+    ret=0;
+    throw;
+  }
+}
+
+sl4_list_t *SystemCommon::sl4_syscom_get_string(int n, int *dim, 
+                                                  int *index) {
+  int i, d, size;
+  sl4_list_t *lst;
+  string *str = NULL;
+  sl4_string_t *tmp = NULL;
+  lst = sl4_list_new();
+  if(lst == NULL)
+    return NULL;
+  if(n<narg){
+    if(VALIDDATAOBJ(argv[n]) && argv[n]->TypeofOBJ()==SL_OBJ::STRING_O){
+      d = argv[n]->GetBufferPointer()->GetDim();
+      *dim = d;
+      for(i=0; i<d; i++){
+        index[i]=argv[n]->GetBufferPointer()->GetIndex(i);
+      }
+      size = IndexSize(*dim, index);
+      str = (string*)argv[n]->GetBufferPointer()->GetDataPointer();
+      for(i = 0; i<size; i++){
+        tmp = sl4_string_new_cstr(str[i].c_str());
+        sl4_list_push_back(lst, tmp);
+      }
+    }
+  }
+  return lst;
+}
+
 int   SystemCommon::SCGetBufferID(int n){
   if(n-1<=narg && argv[n] != 0) 
     return n;
