@@ -9,7 +9,7 @@
 #undef  DLLIMPORT
 #endif
 
-#ifdef  WIN32
+#if defined(WIN32) || defined(__CYGWIN__)
 #define DLLEXPORT __declspec(dllexport)
 #define DLLIMPORT __declspec(dllimport)
 #else
