@@ -25,7 +25,7 @@
  * THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-/* $Id: tty_console.cpp,v 1.8 2005/03/31 02:46:23 orrisroot Exp $ */
+/* $Id: tty_console.cpp,v 1.10 2005/10/27 04:23:56 orrisroot Exp $ */
 #define  LIBSATELLITE_EXPORTS
 
 #ifdef HAVE_CONFIG_H
@@ -161,7 +161,8 @@ size_t tty_console::editbuf_length(size_t p){
 }
 
 void tty_console::editbuf_print(){
-  size_t i,tcol;
+  size_t i;
+  int tcol;
   int kanji=0;
   char c;
   cursor_goto_pos(0);
@@ -618,7 +619,7 @@ int tty_console::keyevent_cut_region(int c){
   len=(int)(max-min); /* TODO: remove cast */
   if(len==0) return 1;
   history_standby(hist);
-  cutbuf=ebuf.substr(min,len);
+  sl4_string_set_cstr(str_cutbuf, ebuf.substr(min,len).c_str());
   cursor_goto_pos(min);
   _keyevent_ndelete(len);
   return 1;
@@ -632,12 +633,12 @@ int tty_console::keyevent_yank(int c){
     input_lock=false;
     term_hide_help();
   }
-  if(cutbuf.empty()) return 1;
-  len=cutbuf.length();
+  if(sl4_string_empty(str_cutbuf)) return 1;
+  len = sl4_string_length(str_cutbuf);
   if(ebuf.length()+len>=ONELINE) return 1;
   history_standby(hist);
   for(i=0;i<len;i++){
-    editbuf_insert(cutbuf[i],pos+i);
+    editbuf_insert(sl4_string_get_at(str_cutbuf,i),pos+i);
   }
   tmp_pos=pos+len;
   editbuf_print();
@@ -660,7 +661,7 @@ int tty_console::keyevent_kill_eol(int c){
   len=(int)(max-min); /* TODO: remove cast */
   if(len==0) return 1;
   history_standby(hist);
-  cutbuf=ebuf.substr(min,len);
+  sl4_string_set_cstr(str_cutbuf, ebuf.substr(min,len).c_str());
   cursor_goto_pos(min);
   _keyevent_ndelete(len);
   return 1;
@@ -920,13 +921,14 @@ int tty_console::keyevent_list_satcom(int c){
 void tty_console::prompt_print(){
   char buf[_MAX_PATH];
   string pmes,tmp_str;
-  string::iterator it;
+  size_t it, len;
   prompt_length = 0;
-  for(it=prompt[cur_prompt_no].begin();it!=prompt[cur_prompt_no].end();it++){
-    if(*it == '%'){
+  len = sl4_string_length(str_prompt[cur_prompt_no]);
+  for(it=0; it < len; it++){
+    if(sl4_string_get_at(str_prompt[cur_prompt_no], it) == '%'){
       it++;
-      if(it!=prompt[cur_prompt_no].end()){
-        switch (*it){
+      if(it < len){
+        switch ( sl4_string_get_at(str_prompt[cur_prompt_no], it) ){
         case '%': pmes+= "%"; prompt_length++; break;
         case '!': 
           snprintf(buf, _MAX_PATH, "%d", lineno);
@@ -940,7 +942,7 @@ void tty_console::prompt_print(){
           }
           break;
         case 'p': 
-          tmp_str += prompt_fmt_p(); 
+          tmp_str += prompt_fmt_p();
           pmes += tmp_str;
           prompt_length += tmp_str.length();
           break;
@@ -965,7 +967,7 @@ void tty_console::prompt_print(){
       }
     }else{
       prompt_length++;
-      pmes+=*it;
+      pmes += sl4_string_get_at(str_prompt[cur_prompt_no], it);
     }
   }
   if(!pmes.empty()) term_print(pmes.c_str());
@@ -1070,12 +1072,13 @@ void tty_console::set_keybind_default(){
 tty_console::tty_console() :
   in_pipe(false), use_term_vbell(true), 
   input_lock(false), input_lock_len(0), input_lock_less(0), prompt_length(0), 
-  cur_prompt_no(0), hint_buf(0),
-  file_name(0){
+  cur_prompt_no(0){
   string hfile;
   char tmp[_MAX_PATH];
   static char *format1="[%R]SATELLITE[%N]%p:[%!]%% ";
   static char *format2="+ ";
+  hint_buf = NULL;
+  file_name = NULL;
   hist = (history_t*)malloc(sizeof(history_t));
   commands = hash_table_str_new();
   history_init(hist);
@@ -1085,8 +1088,6 @@ tty_console::tty_console() :
     hfile += HISTORY_FILE;
     history_set_fname(hist,hfile.c_str());
   }
-  prompt[0] = format1;
-  prompt[1] = format2;
   lineno = hist->size+1;
   /* key event assign */
   kfuncs[SL_TTY::KEYEVENT_IGNORE]       = &tty_console::keyevent_ignore;
@@ -1125,6 +1126,10 @@ tty_console::tty_console() :
   input_filept = sl4_stack_new();
   input_lineno = sl4_stack_new();
   input_fname  = sl4_stack_new();
+
+  str_cutbuf = sl4_string_new();   // cut buffer
+  str_prompt[0] = sl4_string_new_cstr(format1); // prompt string 1
+  str_prompt[1] = sl4_string_new_cstr(format2); // prompt string 2
 }
 
 void tty_console::term_clear_screen(){
@@ -1221,6 +1226,10 @@ tty_console::~tty_console(){
   free(input_filept);
   free(input_lineno);
   free(input_fname);
+  // free string buffer
+  sl4_string_delete(str_cutbuf);
+  sl4_string_delete(str_prompt[0]);
+  sl4_string_delete(str_prompt[1]);
 }
 
 void tty_console::execerror(const char *str, const char *str2){
@@ -1438,11 +1447,11 @@ void tty_console::satcom_db_del(module_command_t *cmd){
 }
 
 void tty_console::prompt_set(const char *fmt, int n){
-  prompt[n] = fmt;
+  sl4_string_set_cstr(str_prompt[n], fmt);
 }
 
 void tty_console::prompt_get(char *fmt, int size, int n){
-  strncpy(fmt,prompt[n].c_str(),size);
+  strncpy(fmt, sl4_string_get_cstr(str_prompt[n]), size);
 }
 
 // prompt format - %p
