@@ -25,7 +25,7 @@
  * THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-/* $Id: LexicalAnalizer.cpp,v 1.5 2005/01/25 12:29:17 orrisroot Exp $ */
+/* $Id: LexicalAnalizer.cpp,v 1.6 2005/06/29 15:24:32 orrisroot Exp $ */
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
@@ -100,8 +100,6 @@ bool LexicalAnalizer::moreinput(int yyparse_flag){
       return true;
     }
     return false; 
-    /* } else contflag=true;
-       stackmachine->Program_Init(); */
   }
   return contflag;
 }
@@ -309,6 +307,7 @@ int LexicalAnalizer::token(){
   if(!strcmp(sbuf,"exit")){       return 0; }
   if(!strcmp(sbuf,"Module_Dll")){ return MODULE_DLL; }
   if(!strcmp(sbuf,"Module_Ini")){ return MODULE_INI; }
+  if(!strcmp(sbuf,"Module_Scr")){ return MODULE_SCR; }
   if(!strcmp(sbuf,"module")){     return MODULE; }
   if(!strcmp(sbuf,"define")){     return DEFINE; }
   if(!strcmp(sbuf,"inline")){     return INLINE; }
