@@ -25,7 +25,7 @@
  * THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-/* $Id: StackMachine.cpp,v 1.19 2005/02/17 08:53:07 orrisroot Exp $ */
+/* $Id: StackMachine.cpp,v 1.22 2005/11/10 13:54:14 orrisroot Exp $ */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -306,7 +306,7 @@ SL_Object *StackMachine::eval_program(const char *str){
     // change program list
     vmstat.prog=new Program_List;
     // push eval program list 
-    eval_stack.push(vmstat.prog);
+    eval_stack.push(plist);
     // parse
 #if defined(_DEBUG) && defined(_DEBUG_CODE)
     console->tty_printf(" -> LexicalAnalizer::yyparse()");
@@ -318,33 +318,37 @@ SL_Object *StackMachine::eval_program(const char *str){
       try{
         Program_Run(vmstat.prog->Get_Top()); // program run
       }catch(execerr_exception){
-        delete eval_stack.top();
+        delete vmstat.prog;
+        vmstat.prog = eval_stack.top();
         eval_stack.pop();
-        vmstat.prog=plist;
         vmstat.prog->Set_PC(pc);
         in_eval = previneval;
         throw;
       }catch(bad_alloc){
-        delete eval_stack.top();
+        delete vmstat.prog;
+        vmstat.prog = eval_stack.top();
         eval_stack.pop();
-        vmstat.prog=plist;
         vmstat.prog->Set_PC(pc);
         in_eval = previneval;
         throw;
       }catch(buffer_exception){
-        delete eval_stack.top();
+        delete vmstat.prog;
+        vmstat.prog = eval_stack.top();
         eval_stack.pop();
-        vmstat.prog=plist;
         vmstat.prog->Set_PC(pc);
         in_eval = previneval;
         throw;
       }
     }
+    if( eval_stack.empty() ){
+      // parser error : recovery() already finised
+      throw execerr_exception();
+    }
     // pop eval program list
-    delete eval_stack.top();
-    eval_stack.pop();
+    delete vmstat.prog;
     // recover program list
-    vmstat.prog=plist;
+    vmstat.prog = eval_stack.top();
+    eval_stack.pop();
     // run next program
 #if defined(_DEBUG) && defined(_DEBUG_CODE)
     console->tty_printf(" -> (program run next) in %s\n",where);
@@ -392,7 +396,8 @@ void StackMachine::recovery(){ // initialize for sub code generation
   if(in_eval){
     // error in eval
     while(!eval_stack.empty()){
-      delete eval_stack.top();
+      delete vmstat.prog;
+      vmstat.prog = eval_stack.top();
       eval_stack.pop();
     }
     in_eval=false;
@@ -1952,6 +1957,7 @@ void StackMachine::module_install(){
   satcom_install_symtab_for_arg_t arg;
   symbol_t *sym;
   module_t *mod;
+  const char *scr;
 
   sym=vmstat.prog->Get_PC()->GetSymbol(); vmstat.prog->Inc_PC();
 
@@ -1959,6 +1965,7 @@ void StackMachine::module_install(){
   if(mod == NULL){
     console->execerror("can't load module",sym->name);
   }
+
   // load module
   if(module_load(mod)!=0){
     //#ifdef WIN32
@@ -1975,10 +1982,29 @@ void StackMachine::module_install(){
   console->tty_printf("   : %3d External Functions ... Install Ok.\n",
                       mod->commands->nkeys);
 
+  // register initial shell script
+  scr = module_getscript(mod);
+  if(scr != NULL){
+    // convert string to object
+    SL_Object   *obj;
+    Base_Buffer *buf;
+    Index pt;
+    buf=new String_Buffer;
+    buf->SetIndex(0,1); buf->SetDim(1); buf->InitBuffer();
+    pt.SetIndex(0,0);   pt.SetDim(1);
+    ((String_Buffer *)buf)->SetString(pt, scr);
+    obj=new_SL_Object(SL_OBJ::STRING_O, buf);
+    // push object
+    push_obj(obj);
+    // do inline
+    begin_inline();
+  }
+
   // install satellite commands to global symbol list
   arg.console = console;
   arg.symtab  = syscom->gl_symtab;
   hash_table_foreach(mod->commands, satcom_install_symtab_for, &arg);
+
 }
 
 // module_define_begin(sym)
@@ -2072,6 +2098,18 @@ void StackMachine::module_setfile(){
         throw bad_alloc(); 
       }
       break;
+    case VMCODE_MODULE_DEFINE_SCR: // part of 'set Module_Scr "hoge.sl"'
+      if(Access(name,SL_FATTR_ROK) != 0){
+        err_msg="module ";
+        err_msg+=vmstat.module->module_name;
+        err_msg+=", can not read file ";
+        err_msg+=name;
+        console->execerror(0,err_msg.c_str());
+      }
+      if(module_set_scr(vmstat.module,name) != 0){ 
+        throw bad_alloc(); 
+      }
+      break;
     }
   }
 }
@@ -2198,7 +2236,9 @@ void StackMachine::module_print(){
   if(mod->dll_file!=0 && mod->dll_file[0]!='\0')
     console->tty_printf("\t set Module_Dll \"%s\"\n",mod->dll_file);
   if(mod->ini_file!=0 && mod->ini_file[0]!='\0')
-  console->tty_printf("\t set Module_Ini \"%s\"\n",mod->ini_file);
+    console->tty_printf("\t set Module_Ini \"%s\"\n",mod->ini_file);
+  if(mod->scr_file!=0 && mod->scr_file[0]!='\0')
+    console->tty_printf("\t set Module_Scr \"%s\"\n",mod->scr_file);
   console->tty_printf("}\n");
 }
 
