@@ -11,7 +11,7 @@
 # undef DECLSPEC
 #endif
 
-#ifdef WIN32
+#if defined(WIN32) || defined(__CYGWIN__)
 #  define DLLEXPORT __declspec(dllexport)
 #  define DLLIMPORT __declspec(dllimport)
 # ifdef LIBSLSHELL_EXPORTS
