@@ -1,6 +1,5 @@
 /* 
- * Copyright (c) 2003 RIKEN (The Institute of Physical and Chemical Research)
- * All rights reserved.
+ * Copyright (c) 2003-2005 RIKEN Japan, All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -26,7 +25,7 @@
  * THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-/* $SATELLITE: satellite4/modules/gpm/gpmwin/win32.c,v 1.26 2004/09/01 08:31:11 orrisroot Exp $ */
+/* $Id: win32.c,v 1.29 2005/10/28 00:14:33 orrisroot Exp $ */
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -34,12 +33,16 @@
 
 #ifdef WIN32
 
+#pragma warning(disable:4312)
+// warning C4312: 'type cast' : conversion from 'LONG' to 'HINSTANCE' of greater size
+
 #include <windows.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <math.h>
 
+#include "res\gpmwin_res.h"
 #include "libgpm.h"
 #include "gpmwinpriv.h"
 
@@ -55,12 +58,16 @@ extern "C" {
 # define M_PI 3.14159265358979323846
 #endif
 
+#define COORD_WIDTH  110
+#define COORD_HEIGHT  16
+
 extern int    paper, orient;
 extern double height, width;
 
 typedef struct _gpm_win32_t {
   CRITICAL_SECTION cs;
   BOOL       IsWinNT;
+  BOOL       bShowCoord;
   WNDCLASSEX klass;
   HINSTANCE  hInst;
   HWND       hMainWnd;
@@ -77,6 +84,8 @@ typedef struct _gpm_win32_t {
   int        pen_func;
   HBITMAP    hBitmap;
   HDC        hBuffer;
+  HBITMAP    hBitmapCoord;
+  HDC        hBufferCoord;
   HFONT      hMousePosFont;
   int        InLoop;
 } gpm_win32_t;
@@ -109,7 +118,7 @@ static int gpmwin_regist_class(WNDCLASSEX *klass, WNDPROC winProc,
   klass->cbClsExtra = 0;
   klass->cbWndExtra = 0;
   klass->hInstance = hInst; /* owner of the class: mandatory */
-  klass->hIcon = NULL; /* icon resources */
+  klass->hIcon = LoadIcon(hInst, MAKEINTRESOURCE(IDI_MAIN_ICON)); /* icon resources */
   klass->hIconSm = NULL;
   klass->hCursor = LoadCursor(0, IDC_ARROW); /* optional */
   klass->hbrBackground = GetStockObject(GRAY_BRUSH); /* optional */
@@ -127,7 +136,7 @@ int gpmwin_init(int argc, char *argv[]){
   GetVersionEx(&osvi);
   InitializeCriticalSection(&w32cont.cs);
   w32cont.IsWinNT = (osvi.dwPlatformId == VER_PLATFORM_WIN32_NT);
-  w32cont.hInst = GetModuleHandle(NULL);
+  w32cont.hInst = (HINSTANCE)argv; //GetModuleHandle(NULL);
   w32cont.pen_dash_type = GPM_LINE_TYPE_SOLID;
   w32cont.pen_func = PENFUNC_COPY;
   w32cont.hMousePosFont = CreateFont(
@@ -149,6 +158,9 @@ int gpmwin_init(int argc, char *argv[]){
     return -1;
   w32cont.hBitmap = NULL;
   w32cont.hBuffer = NULL;
+  w32cont.hBitmapCoord = NULL;
+  w32cont.hBufferCoord = NULL;
+  w32cont.bShowCoord = TRUE;
   return gpmwin_regist_class(&w32cont.klass, gpmwin_proc, 
                              gpmwin_className, w32cont.hInst);
 }
@@ -308,6 +320,8 @@ int gpmwin_mainloop(){
     WaitForSingleObject(gpmwin_hThread, INFINITE);
     CloseHandle(gpmwin_hThread);
   }
+  DeleteDC(w32cont.hBufferCoord);
+  DeleteObject(w32cont.hBitmapCoord);
   DeleteDC(w32cont.hBuffer);
   DeleteObject(w32cont.hBitmap);
   DeleteObject(w32cont.hMousePosFont);
@@ -319,9 +333,23 @@ LRESULT CALLBACK gpmwin_proc(HWND hwnd, unsigned int message,
                              WPARAM wParam, LPARAM lParam){
   HDC hdc;
   PAINTSTRUCT ps;
+  POINT pt;
+  HMENU hmenu, hSubmenu;
   LPMINMAXINFO lpmmi;
   RECT rc;
+  HINSTANCE hinst;
   switch(message){
+  case WM_COMMAND:
+    switch (LOWORD(wParam)){
+    case IDM_SHOW_HIDE_COORDLABEL:
+      w32cont.bShowCoord =! w32cont.bShowCoord;
+      draw_coord(&rc);
+      InvalidateRect(w32cont.hMainWnd, &rc, FALSE);
+      break;
+    default:
+      return DefWindowProc(hwnd, message, wParam, lParam);
+    }
+    break;
   case WM_CHAR:
     switch((UINT)wParam){
     case 0x11: /* Cntl-Q */
@@ -337,6 +365,20 @@ LRESULT CALLBACK gpmwin_proc(HWND hwnd, unsigned int message,
   case WM_LBUTTONUP:
     copy_coord_to_clipboard(hwnd);
     return 0;
+  case WM_RBUTTONDOWN:
+    pt.x = LOWORD(lParam);
+    pt.y = HIWORD(lParam);
+    hinst = (HINSTANCE)GetWindowLong(hwnd, GWL_HINSTANCE);
+    hmenu = LoadMenu(hinst, MAKEINTRESOURCE(IDR_POPUPMENU));
+    if(w32cont.bShowCoord){
+      hSubmenu = GetSubMenu(hmenu, 0);
+    }else{
+      hSubmenu = GetSubMenu(hmenu, 1);
+    }
+    ClientToScreen(hwnd, &pt);
+    TrackPopupMenu(hSubmenu, TPM_LEFTALIGN, pt.x, pt.y, 0, hwnd, NULL);
+    DestroyMenu(hmenu);
+    break;
   case WM_GETMINMAXINFO:
     /* limit max and min window size */
     lpmmi = (LPMINMAXINFO)lParam;
@@ -372,6 +414,10 @@ LRESULT CALLBACK gpmwin_proc(HWND hwnd, unsigned int message,
            ps.rcPaint.right - ps.rcPaint.left, 
            ps.rcPaint.bottom - ps.rcPaint.top, w32cont.hBuffer, 
            ps.rcPaint.left, ps.rcPaint.top, SRCCOPY);
+    if(w32cont.bShowCoord){
+      BitBlt(hdc, 0, 0, COORD_WIDTH, COORD_HEIGHT, w32cont.hBufferCoord, 
+             0, 0, SRCCOPY);
+    }
     EndPaint(hwnd, &ps);
     LeaveCriticalSection(&w32cont.cs);
     return 0;
@@ -424,6 +470,7 @@ static HPEN create_pen(){
 }
 
 static void create_bitmap_buffer(HDC hdc){
+  /* buffer for drawing area */
   if(w32cont.hBuffer != NULL){
     DeleteDC(w32cont.hBuffer);
   }
@@ -435,6 +482,18 @@ static void create_bitmap_buffer(HDC hdc){
   SelectObject(w32cont.hBuffer , w32cont.hBitmap);
   SelectObject(w32cont.hBuffer , GetStockObject(NULL_PEN));
   PatBlt(w32cont.hBuffer, 0, 0, w32cont.x, w32cont.y, WHITENESS);
+  /* buffer for coordination */
+  if(w32cont.hBufferCoord != NULL){
+    DeleteDC(w32cont.hBufferCoord);
+  }
+  if(w32cont.hBitmapCoord != NULL){
+    DeleteObject(w32cont.hBitmapCoord);
+  }
+  w32cont.hBitmapCoord = CreateCompatibleBitmap(hdc, COORD_WIDTH, COORD_HEIGHT);
+  w32cont.hBufferCoord = CreateCompatibleDC(hdc);
+  SelectObject(w32cont.hBufferCoord, w32cont.hBitmapCoord);
+  SelectObject(w32cont.hBufferCoord, GetStockObject(NULL_PEN));
+  PatBlt(w32cont.hBufferCoord, 0, 0, COORD_WIDTH, COORD_HEIGHT, WHITENESS);
 }
 
 static void  draw_coord(RECT *rc){
@@ -445,28 +504,30 @@ static void  draw_coord(RECT *rc){
   HPEN  hPen, hOldPen;
   HFONT hOldFont;
   EnterCriticalSection(&w32cont.cs);
-  x = w32cont.mx;
-  y = w32cont.my;
-  libgpm_pixel2mm(paper, &posx, &posy, x, y);
-  posy = height - posy;
-  if(posy < 0.0) posy = 0.0;
-  snprintf(buf, 32, "(%5.1f, %5.1f)", posx, posy);
-
+  rect.top = 0; rect.left = 0; rect.right = COORD_WIDTH; rect.bottom = COORD_HEIGHT;
   /* draw background rectangle */
-  rect.top = 0; rect.left = 0; rect.right = 110; rect.bottom = 16;
   hPen    = CreatePen(PS_SOLID, 1, w32cont.bgcolor);
-  hOldPen = SelectObject(w32cont.hBuffer, hPen);
-  Rectangle(w32cont.hBuffer, rect.top, rect.left, rect.right, rect.bottom);
-  SelectObject(w32cont.hBuffer, hOldPen);
-  DeleteObject(hPen);
-  /* draw string */
-  hPen     = CreatePen(PS_SOLID, 1, w32cont.fgcolor);
-  hOldPen  = SelectObject(w32cont.hBuffer, hPen);
-  hOldFont = SelectObject(w32cont.hBuffer, w32cont.hMousePosFont);
-  TextOut(w32cont.hBuffer, 0, 0, buf, lstrlen(buf));
-  SelectObject(w32cont.hBuffer, hOldPen);
-  SelectObject(w32cont.hBuffer, hOldFont);
+  hOldPen = SelectObject(w32cont.hBufferCoord, hPen);
+  Rectangle(w32cont.hBufferCoord, rect.top, rect.left, rect.right, rect.bottom);
+  SelectObject(w32cont.hBufferCoord, hOldPen);
   DeleteObject(hPen);
+  if(w32cont.bShowCoord){
+    x = w32cont.mx;
+    y = w32cont.my;
+    libgpm_pixel2mm(paper, &posx, &posy, x, y);
+    posy = height - posy;
+    if(posy < 0.0) posy = 0.0;
+    snprintf(buf, 32, "(%5.1f, %5.1f)", posx, posy);
+
+    /* draw string */
+    hPen     = CreatePen(PS_SOLID, 1, w32cont.fgcolor);
+    hOldPen  = SelectObject(w32cont.hBufferCoord, hPen);
+    hOldFont = SelectObject(w32cont.hBufferCoord, w32cont.hMousePosFont);
+    TextOut(w32cont.hBufferCoord, 0, 0, buf, lstrlen(buf));
+    SelectObject(w32cont.hBufferCoord, hOldPen);
+    SelectObject(w32cont.hBufferCoord, hOldFont);
+    DeleteObject(hPen);
+  }
   if(rc != NULL){
     *rc = rect;
   }
