@@ -1,6 +1,5 @@
 /* 
- * Copyright (c) 2003 RIKEN (The Institute of Physical and Chemical Research)
- * All rights reserved.
+ * Copyright (c) 2003-2005 RIKEN Japan, All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -26,7 +25,7 @@
  * THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-/* $SATELLITE: satellite4/modules/gpm/gpmwin/x11.c,v 1.20 2004/08/11 13:58:02 orrisroot Exp $ */
+/* $Id: x11.c,v 1.23 2005/10/29 10:18:55 orrisroot Exp $ */
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -45,6 +44,7 @@
 #include <X11/StringDefs.h>
 #include <X11/Xatom.h>
 #include <X11/Xlocale.h>
+#include <X11/xpm.h>
 
 /* athena wiget */
 #ifdef HAVE_XAW3D
@@ -53,16 +53,21 @@
 # include <X11/Xaw3d/Label.h>
 # include <X11/Xaw3d/Simple.h>
 # include <X11/Xaw3d/Viewport.h>
+# include <X11/Xaw3d/SimpleMenu.h>
+# include <X11/Xaw3d/SmeBSB.h>
 #else
 # include <X11/Xaw/Cardinals.h>
 # include <X11/Xaw/Form.h>
 # include <X11/Xaw/Label.h>
-# include <X11/Xaw/Viewport.h>
 # include <X11/Xaw/Simple.h>
+# include <X11/Xaw/Viewport.h>
+# include <X11/Xaw/SimpleMenu.h>
+# include <X11/Xaw/SmeBSB.h>
 #endif
 
 #include "libgpm.h"
 #include "gpmwinpriv.h"
+#include "res/gpmwin.xpm"
 
 #ifdef __cplusplus
 extern "C" {
@@ -90,12 +95,15 @@ static void exceptinput_event(XtPointer pt, int *p, XtInputId * id);
 static void dispcoord_event(Widget w, XtPointer cil_data, XEvent *ev);
 static void getcoord_event(Widget w, XtPointer cil_data, XEvent *ev);
 
-/* selection call back handlers */
+/* selection callback handlers */
 static Bool sel_convert(Widget w, Atom *selection, Atom *target, Atom *type, 
                         XtPointer *value, unsigned long *length, int *format);
 static void sel_lose();
 static void sel_done();
 
+/* popup menu callback handlers */
+static void pmenu_event(Widget w, XtPointer data, XtPointer spec);
+
 /* color allocation */
 static void color_allocation();
 static void color_alloc_rainbow();
@@ -108,7 +116,7 @@ static void set_tile_pattern(Drawable d, GC gc, double level);
 /* default application and widgets resources */
 static String x11_resources[] = {
   "Wopen*international: True",
-  "Wopen*fontSet: -*-fixed-medium-r-normal--14-*,r14",
+  "Wopen*fontSet: -*-fixed-medium-r-normal--14-*,r14,-*--14-*",
   "Wopen*font: r14",
 #ifdef HAVE_XAW3D
   "Wopen*background: gray80",
@@ -125,9 +133,15 @@ static XtActionsRec x11_actions[] = {
   {NULL, (XtActionProc)NULL}
 };
 
+static Arg toplevel_args[] = {
+  {XtNiconPixmap,      (XtArgVal)NULL},
+  {XtNiconMask,        (XtArgVal)NULL},
+};
+
 static Arg form_args[] = {
   {XtNforeground,      (XtArgVal)NULL},
   {XtNbackground,      (XtArgVal)NULL},
+  {XtNborderWidth,     (XtArgVal)0},
   {XtNdefaultDistance, (XtArgVal)0},
 };
 
@@ -146,6 +160,7 @@ static Arg label_args[] = {
 static Arg view_args[] = {
   {XtNwidth,           (XtArgVal)NULL},
   {XtNheight,          (XtArgVal)NULL},
+  {XtNborderWidth,     (XtArgVal)0},
   {XtNallowHoriz,      (XtArgVal)True},
   {XtNallowVert,       (XtArgVal)True},
   {XtNuseBottom,       (XtArgVal)True},
@@ -160,12 +175,36 @@ static Arg frame_args[] = {
   {XtNborderWidth,     (XtArgVal)0},
 };
 
+static Arg pmenu_args[] = {
+  {XtNforeground,      (XtArgVal)NULL},
+  {XtNbackground,      (XtArgVal)NULL},
+  {XtNborderWidth,     (XtArgVal)0},
+};
+
+static XtCallbackRec pmenu_cb[2] = {
+  {NULL, NULL}, {NULL, NULL}
+};
+
+static Arg pmentry1_args[] = {
+  {XtNforeground,      (XtArgVal)NULL},
+  {XtNbackground,      (XtArgVal)NULL},
+  {XtNcallback,        (XtArgVal)NULL},
+  {XtNlabel,           (XtArgVal)NULL},
+  {XtNborderWidth,     (XtArgVal)0},
+};
+
+static const char *pmentry1_label[] = {
+  "Hide coordinate label",
+  "Show coordinate label"
+};
+
 static String toplebel_trans_table_str = 
   "<Message>WM_PROTOCOLS: Quit()";
 
 static String frame_trans_table_str = 
   "Ctrl<Key>Q: Quit()\n"
   "Ctrl<Key>W: Erase()\n"
+  "<Btn3Down>: XawPositionSimpleMenu(pmenu) MenuPopup(pmenu)\n"
   "<Expose>: Expose()";
 
 
@@ -179,12 +218,15 @@ typedef struct _gpm_x11_t {
   Pixmap        pixmap;
   unsigned long fgcolor;
   unsigned long bgcolor;
-  unsigned long gray_color;
+  unsigned long gray50_color, gray80_color;
   unsigned long color[GPM_COLOR_SIZE];
   unsigned long rainbow[GPM_RAINBOW_BASECOL*GPM_RAINBOW_DIVNUM+2];
   unsigned long gradation[7][GPM_RAINBOW_BASECOL*GPM_RAINBOW_DIVNUM+2];
+  Window        root;
   Window        window;
   Widget        toplevel, form, label, view, frame;
+  Widget        pmenu, pmentry1;
+  int           label_visible;
   XtAppContext  app_con;
   unsigned int  wx, wy;
 } gpm_x11_t;
@@ -232,6 +274,8 @@ int create_frame_pixmap(int x, int y){
 int gpmwin_create(int x, int y, const char *title){
   XtTranslations trans_table;
   XColor c,cc;
+  Pixmap icon_pixmap, icon_mask;
+  int errcode;
 
   x11cont.wx = (unsigned int)x;
   x11cont.wy = (unsigned int)y;
@@ -239,9 +283,20 @@ int gpmwin_create(int x, int y, const char *title){
   /* get display informations */
   x11cont.display = XtDisplay(x11cont.toplevel);
   x11cont.screen  = DefaultScreen(x11cont.display);
+  x11cont.root    = DefaultRootWindow(x11cont.display);
   x11cont.cmap    = DefaultColormap(x11cont.display, x11cont.screen);
   x11cont.depth   = DefaultDepth(x11cont.display, x11cont.screen);
 
+  /* add application icon */
+  errcode = XpmCreatePixmapFromData(x11cont.display, x11cont.root,
+                                    gpmwin_xpm, &icon_pixmap, &icon_mask,
+                                    NULL);
+  if( errcode == 0 ){
+    toplevel_args[0].value = (XtArgVal)icon_pixmap;
+    toplevel_args[1].value = (XtArgVal)icon_mask;
+    XtSetValues(x11cont.toplevel, toplevel_args, XtNumber(toplevel_args));
+  }
+
   /* add application actions */
   XtAppAddActions(x11cont.app_con, x11_actions, XtNumber(x11_actions));
 
@@ -254,9 +309,12 @@ int gpmwin_create(int x, int y, const char *title){
   /* set colors */
   x11cont.fgcolor = BlackPixel(x11cont.display, x11cont.screen);
   x11cont.bgcolor = WhitePixel(x11cont.display, x11cont.screen);
-  x11cont.gray_color = x11cont.bgcolor;
+  x11cont.gray50_color = x11cont.bgcolor;
   if(XAllocNamedColor(x11cont.display, x11cont.cmap, "gray50", &c, &cc))
-     x11cont.gray_color = c.pixel;
+    x11cont.gray50_color = c.pixel;
+  x11cont.gray80_color = x11cont.bgcolor;
+  if(XAllocNamedColor(x11cont.display, x11cont.cmap, "gray80", &c, &cc))
+    x11cont.gray80_color = c.pixel;
   
   /* create child widgets */
   view_args[0].value = (XtArgVal)x11cont.wx;
@@ -266,7 +324,7 @@ int gpmwin_create(int x, int y, const char *title){
                                        XtNumber(view_args));
 
   form_args[0].value = (XtArgVal)x11cont.fgcolor;
-  form_args[1].value = (XtArgVal)x11cont.gray_color;
+  form_args[1].value = (XtArgVal)x11cont.gray50_color;
   x11cont.form = XtCreateManagedWidget("form", formWidgetClass, 
                                        x11cont.view, form_args, 
                                        XtNumber(form_args));
@@ -276,9 +334,10 @@ int gpmwin_create(int x, int y, const char *title){
   x11cont.label = XtCreateManagedWidget("label", labelWidgetClass,
                                         x11cont.form, label_args, 
                                         XtNumber(label_args));
+  x11cont.label_visible = 1;
 
   frame_args[0].value = (XtArgVal)x11cont.fgcolor;
-  frame_args[1].value = (XtArgVal)x11cont.gray_color;
+  frame_args[1].value = (XtArgVal)x11cont.gray50_color;
   frame_args[2].value = (XtArgVal)x11cont.wx;
   frame_args[3].value = (XtArgVal)x11cont.wy;
   x11cont.frame = XtCreateManagedWidget("frame", simpleWidgetClass, 
@@ -287,6 +346,24 @@ int gpmwin_create(int x, int y, const char *title){
   trans_table = XtParseTranslationTable(frame_trans_table_str);
   XtOverrideTranslations(x11cont.frame, trans_table);
 
+  /* set popup menu */
+  pmenu_args[0].value = (XtArgVal)x11cont.fgcolor;
+  pmenu_args[1].value = (XtArgVal)x11cont.gray80_color;
+  x11cont.pmenu = XtCreatePopupShell("pmenu", simpleMenuWidgetClass,
+                                     x11cont.toplevel, pmenu_args,
+                                     XtNumber(pmenu_args));
+
+  pmenu_cb[0].callback = pmenu_event;   /* set callback handler */
+  pmenu_cb[0].closure  = (XtPointer)0;
+  pmentry1_args[0].value = (XtArgVal)x11cont.fgcolor;
+  pmentry1_args[1].value = (XtArgVal)x11cont.gray80_color;
+  pmentry1_args[2].value = (XtArgVal)pmenu_cb;
+  pmentry1_args[3].value = (XtArgVal)pmentry1_label[0];
+  x11cont.pmentry1 = XtCreateManagedWidget("pmentry1",
+                                           smeBSBObjectClass,
+                                           x11cont.pmenu, pmentry1_args,
+                                           XtNumber(pmentry1_args));
+
   /* add transrations */
   trans_table = XtParseTranslationTable(toplebel_trans_table_str);
   XtOverrideTranslations(x11cont.toplevel, trans_table);
@@ -381,7 +458,7 @@ int gpmwin_erase(){
 }
 
 int gpmwin_resize(const char *title, int w, int h){
-  XSetForeground(x11cont.display, x11cont.gc, x11cont.gray_color);
+  XSetForeground(x11cont.display, x11cont.gc, x11cont.gray50_color);
   XFillRectangle(x11cont.display, x11cont.window, x11cont.gc, 0, 0, 
                  x11cont.wx, x11cont.wy);
   XFreePixmap(x11cont.display, x11cont.pixmap);
@@ -614,6 +691,26 @@ static Bool sel_convert(Widget w, Atom *selection, Atom *target, Atom *type,
 static void sel_lose(){}
 static void sel_done(){}
 
+/* popup menu callback handlers */
+static void pmenu_event(Widget w, XtPointer data, XtPointer spec){
+  int menuid = (int)data;
+  if( menuid == 0 ){
+    if( x11cont.label_visible == 0 ){
+      /* visible label */
+      XtMapWidget(x11cont.label);
+      pmentry1_args[3].value = (XtArgVal)pmentry1_label[0];
+      XtSetValues(x11cont.pmentry1, pmentry1_args, XtNumber(pmentry1_args));
+      x11cont.label_visible = 1;
+    } else {
+      /* invisible label */
+      XtUnmapWidget(x11cont.label);
+      pmentry1_args[3].value = (XtArgVal)pmentry1_label[1];
+      XtSetValues(x11cont.pmentry1, pmentry1_args, XtNumber(pmentry1_args));
+      x11cont.label_visible = 0;
+    }
+  }
+}
+
 /* color allocation */
 static void color_allocation(){
   int i;
