@@ -25,7 +25,7 @@
  * THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-/* $SATELLITE: satellite4/modules/gpm/lib/gpmcmd.c,v 1.27 2005/01/09 20:56:50 orrisroot Exp $ */
+/* $Id: gpmcmd.c,v 1.29 2005/10/30 09:55:30 orrisroot Exp $ */
 
 #define GPMCMD_C_SOURCE
 
@@ -33,7 +33,7 @@
 # include "config.h"
 #endif
 
-#ifdef HAVE_WINDOWS_H
+#ifdef WIN32
 # include <windows.h>
 #endif
 
@@ -91,10 +91,10 @@ static void   gplot_static_variables_init();
 static double trans_func(double x1, double y1, double x2, double y2, double x);
 
 
-int checktodvi(){
+int checktodvi(gpm_cont_t *cont){
   int  device;
   int  result;
-  device = (int)GpmCont.device;
+  device = (int)cont->device;
   if(device == GPM_DEVICE_NONE || device == GPM_DEVICE_DISPLAY)
     result = 0;
   else
@@ -106,7 +106,7 @@ int checktodvi(){
 /*********************************************************
  *        gopen                                           *
  *********************************************************/
-int gopen(char pa, char ori, char dev, double pw, double ph){
+int gopen(gpm_cont_t *cont, char pa, char ori, char dev, double pw, double ph){
   int dmx, dmy;
   gpmdev_cont.common.paper       = pa;
   gpmdev_cont.common.orientation = ori;
@@ -123,7 +123,7 @@ int gopen(char pa, char ori, char dev, double pw, double ph){
     /* get window attributes */
     int ix, iy;
     if(libgpm_proto_get_window_attributes(&ix, &iy) != 0){
-      libgpm_window_close(GpmCont.winNum+1);
+      libgpm_window_close(cont, cont->winNum+1);
       return -1;
     }
     gpmdev_cont.win.ixleng = (unsigned int)ix;
@@ -134,7 +134,7 @@ int gopen(char pa, char ori, char dev, double pw, double ph){
   }
   
   if(dev == GPM_DEVICE_DISPFILE || dev == GPM_DEVICE_FILE){
-    libgpm_dvi_open(&gpmdev_cont.dvi, GpmCont.dvifile, 0);
+    libgpm_dvi_open(&gpmdev_cont.dvi, cont->dvifile, 0);
   }
 
   switch(pa){
@@ -552,14 +552,14 @@ void gbox(double x1, double y1, double x2, double y2, int mode, double level){
 /*********************************************************
  *        gerase                                          *
  *********************************************************/
-void gerase(){
+void gerase(gpm_cont_t *cont){
   if(gpmdev_cont.common.device == GPM_DEVICE_DISPFILE ||
      gpmdev_cont.common.device == GPM_DEVICE_FILE){
     libgpm_dvi_close(&gpmdev_cont.dvi);
-    libgpm_dvi_create(GpmCont.dvifile, gpmdev_cont.common.paper,
+    libgpm_dvi_create(cont->dvifile, gpmdev_cont.common.paper,
                       gpmdev_cont.common.orientation, 
                       gpmdev_cont.common.device);
-    libgpm_dvi_open(&gpmdev_cont.dvi, GpmCont.dvifile, 0);
+    libgpm_dvi_open(&gpmdev_cont.dvi, cont->dvifile, 0);
   }
   if(gpmdev_cont.common.device == GPM_DEVICE_DISPLAY ||
      gpmdev_cont.common.device == GPM_DEVICE_DISPFILE)
