@@ -25,7 +25,7 @@
  * THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-/* $SATELLITE: satellite4/modules/gpm/lib/libgpm.h,v 1.33 2005/03/28 11:27:32 orrisroot Exp $ */
+/* $Id: libgpm.h,v 1.36 2005/10/30 09:55:30 orrisroot Exp $ */
 
 #ifndef _LIBGPM_H_
 #define _LIBGPM_H_
@@ -167,7 +167,7 @@
 extern "C" {
 #endif
 
-typedef struct _GpmContext {
+typedef struct _gpm_cont_t {
   /* device parameters */
   char    winNum;                   /* window number (0--MAX_WIN-1)     */
   char    device;                   /* 0: window, 1: win and file, 2: file */
@@ -213,7 +213,7 @@ typedef struct _GpmContext {
   char	  title_x[GPM_ENV_MAX_TITLE][GPM_ENV_MAX_TITLELEN];
   char	  title_y[GPM_ENV_MAX_TITLE][GPM_ENV_MAX_TITLELEN];
   char	  title_z[GPM_ENV_MAX_TITLE][GPM_ENV_MAX_TITLELEN];
-} GpmContext;
+} gpm_cont_t;
 
 
 /* GPMDVIFILE context  */
@@ -350,8 +350,6 @@ typedef struct _gpm_xpoint_t {
 } gpm_xpoint_t;
 
 /* global variable */
-LIBGPM_EXTERN GpmContext GpmCont;
-
 LIBGPM_EXTERN gpmdev_context_t gpmdev_cont; /* device context */
 
 /* comm-unix.c or comm-win32.c */
@@ -363,17 +361,17 @@ int  libgpm_comm_recive_float(double *d);
 int  libgpm_comm_recive_str(char *s, size_t blen, size_t *rlen);
 
 /* rwgpm.c */
-int regpm();
-int wrgpm();
-int chgpm(int num);
+int regpm(gpm_cont_t *cont);
+int wrgpm(gpm_cont_t *cont);
+int chgpm(gpm_cont_t *cont, int num);
 int libgpm_context_init(const char *src_tmpdir);
 int libgpm_context_clean();
 int libgpm_context_settempdir(const char *src_tmpdir);
 
 /* gpmwin.c */
-int libgpm_window_create(int wnum, int paper, int orient, 
-                         double width, double height);
-int libgpm_window_close(int wnum);
+int libgpm_window_create(gpm_cont_t *cont, int wnum, 
+                         int paper, int orient, double width, double height);
+int libgpm_window_close(gpm_cont_t *cont, int wnum);
 
 /* dvifile.c */
 int libgpm_dvi_context_init(gpmdvi_context_t *cont);
@@ -433,8 +431,9 @@ void ps_close();
 
 /* gpm subroutines */
 /* gpmcmd.c */
-int  checktodvi();
-int  gopen(char pa, char ori, char dev, double pw, double ph);
+int  checktodvi(gpm_cont_t *cont);
+int  gopen(gpm_cont_t *cont, char pa, char ori, 
+           char dev, double pw, double ph);
 void gclose();
 void gflush();
 void gnewpen(int color);
@@ -448,7 +447,7 @@ void gscale(double mwin, double ymin, double xmax, double ymax);
 void grainbow(double level);
 void gplot(double x, double y, int ipen_mode);
 void gbox(double x1, double y1, double x2, double y2, int mode, double level);
-void gerase();
+void gerase(gpm_cont_t *cont);
 void gfont(int type);
 void glabel(double x, double y, const char *ichar, double height, 
             double theta, int imode, const char *specialfont);
