@@ -1,6 +1,5 @@
 /* 
- * Copyright (c) 2003 RIKEN (The Institute of Physical and Chemical Research)
- * All rights reserved.
+ * Copyright (c) 2003-2005 RIKEN Japan, All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -26,7 +25,7 @@
  * THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-/* $SATELLITE: satellite4/modules/gpm/lib/psfunc.c,v 1.10 2004/09/02 17:43:05 orrisroot Exp $ */
+/* $Id: psfunc.c,v 1.11 2005/10/30 09:55:30 orrisroot Exp $ */
 
 /*********************************************************
  *                                                        *
@@ -39,7 +38,7 @@
 # include "config.h"
 #endif
 
-#ifdef HAVE_WINDOWS_H
+#ifdef WIN32
 # include <windows.h>
 #endif
 
