@@ -25,7 +25,7 @@
  * THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-/* $Id: nlink.cpp,v 1.4 2005/03/01 15:10:09 orrisroot Exp $ */
+/* $Id: nlink.cpp,v 1.6 2005/11/11 07:43:46 orrisroot Exp $ */
 /*****************************************************************************
   
                     	NCS LINKER COMMAND
@@ -90,7 +90,7 @@ static int create_nlink_makefile_msvc(const char *model, const char *option,
                                       const char *library);
 static int create_nlink_makefile_mingw(const char *model, const char *option, 
                                         const char *library);
-static char *pathname_dos2unix(const char *dos);
+static char *filename_dos2unix(const char *dos);
 /* static char *pathname_unix2dos(const char *unix); */
 #else
 static int create_nlink_makefile_unix(const char *model, const char *option, 
@@ -345,11 +345,11 @@ static int create_nlink_makefile_mingw(const char *model, const char *option,
   len = strlen(sl4prefix_dos);
   if(sl4prefix_dos[len-1] == '\\') sl4prefix_dos[len-1] = '\0';
 
-  sl4prefix = pathname_dos2unix(sl4prefix_dos);
+  sl4prefix = filename_dos2unix(sl4prefix_dos);
   if(sl4prefix == NULL) return 213; /* memory allocation error */
 
   /* get temporary directory */
-  ncs_tmpdir = pathname_dos2unix(get_tmpdir());
+  ncs_tmpdir = filename_dos2unix(get_tmpdir());
   if(ncs_tmpdir == NULL){ free(sl4prefix); return 213; } /* memory allocation error */
 
   /* create a makefile */
@@ -502,7 +502,7 @@ static int create_nlink_makewrapper(const char *model, const char *flag,
   const char *scrext = ".bat";
   /* temporary */
   const char *vcvars_path="C:\\Program Files\\Microsoft Visual Studio .NET2003\\Vc7\\bin";
-  const char *mingw_path="tools\\gcc\\bin";
+  const char *mingw_path="tools\\bin";
   char  sl4drv[_MAX_DRIVE], sl4prefix[_MAX_DIR], sl4path[_MAX_PATH];
   /* get full path info */
   ::GetModuleFileName(NULL, sl4path, _MAX_PATH);
@@ -611,7 +611,7 @@ static void print_link_error_message(const char *model){
 }
 
 #ifdef WIN32
-static char *pathname_dos2unix(const char *dos){
+static char *filename_dos2unix(const char *dos){
   const char *p;
   char *unix;
 #ifndef _VC6
