@@ -1,6 +1,5 @@
 /* 
- * Copyright (c) 2003 RIKEN (The Institute of Physical and Chemical Research)
- * All rights reserved.
+ * Copyright (c) 2003-2005 RIKEN Japan, All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -26,7 +25,7 @@
  * THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-/* $Id: npemake.cpp,v 1.3 2005/03/01 15:10:09 orrisroot Exp $ */
+/* $Id: npemake.cpp,v 1.6 2005/11/11 07:43:47 orrisroot Exp $ */
 /**********************************
 ** create NPE executable program **
 **********************************/
@@ -34,7 +33,7 @@
 #include "config.h"
 #endif /* HAVE_CONFIG_H */
 
-#ifdef HAVE_WINDOWS_H
+#ifdef WIN32
 # include <windows.h>
 #endif
 
@@ -74,7 +73,7 @@ extern "C" {
 
 #ifdef WIN32
 static int  create_npe_makefile_mingw(npe_condition_t *ncond);
-static char *pathname_dos2unix(const char *path);
+static char *filename_dos2unix(const char *path);
 #else
 static int  create_npe_makefile_unix(npe_condition_t *ncond);
 #endif
@@ -174,7 +173,7 @@ static int create_npe_makewrapper(npe_condition_t *ncond){
   FILE *fp;
   char *makewrapper;
 #ifdef WIN32
-  const char *mingw_path="tools\\gcc\\bin";
+  const char *mingw_path="tools\\bin";
   char  tmpdir[_MAX_PATH], *p;
   char  sl4drv[_MAX_DRIVE], sl4prefix[_MAX_DIR], sl4path[_MAX_PATH];
   /* get full path info */
@@ -252,27 +251,27 @@ static int create_npe_makefile_mingw(npe_condition_t *ncond){
   sl4drv = sl4prefix = NULL;
   tmpdir = makefile = NULL;
 
-  mfile = pathname_dos2unix(npe_common->model_file);
-  pfile = pathname_dos2unix(npe_common->penalty_file);
+  mfile = filename_dos2unix(npe_common->model_file);
+  pfile = filename_dos2unix(npe_common->penalty_file);
 
   /* tmpdir */
-  tmpdir = pathname_dos2unix(get_tmpdir());
+  tmpdir = filename_dos2unix(get_tmpdir());
   if(tmpdir == NULL) goto memoryerror;
 
   /* get full path info */
   ::GetModuleFileName(NULL, sl4path, _MAX_PATH);
   /* split drive and directory */
   _splitpath(sl4path, _sl4drv, _sl4prefix, NULL, NULL);
-  sl4drv    = pathname_dos2unix(_sl4drv);
+  sl4drv    = filename_dos2unix(_sl4drv);
   if(sl4drv == NULL) goto memoryerror;
-  sl4prefix = pathname_dos2unix(_sl4prefix);
+  sl4prefix = filename_dos2unix(_sl4prefix);
   if(sl4prefix == NULL) goto memoryerror;
 
   /* model object */
   if(ncond->model_file_type != NPE_FILETYPE_OBJECT){
     tmp = npe_tmpfile_path(get_tmpdir(), MOBJTEMP);
     if(tmp == NULL) goto memoryerror;
-    mobj = pathname_dos2unix(tmp);
+    mobj = filename_dos2unix(tmp);
   }else{
     mobj = strdup(mfile);
   }
@@ -282,7 +281,7 @@ static int create_npe_makefile_mingw(npe_condition_t *ncond){
   if(ncond->penalty_file_type != NPE_FILETYPE_OBJECT){
     tmp = npe_tmpfile_path(get_tmpdir(), POBJTEMP);
     if(tmp == NULL) goto memoryerror;
-    pobj = pathname_dos2unix(tmp);
+    pobj = filename_dos2unix(tmp);
   }else{
     pobj = strdup(pfile);
   }
@@ -545,7 +544,7 @@ static int create_npe_makefile_unix(npe_condition_t *ncond){
 #endif
 
 #ifdef WIN32
-static char *pathname_dos2unix(const char *dos){
+static char *filename_dos2unix(const char *dos){
   const char *p;
   char *unix;
   size_t len;
