@@ -26,7 +26,7 @@
  * THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-/* $Id: bm.cpp,v 1.5 2004/08/23 08:52:31 yoshihiko Exp $ */
+/* $Id: bm.cpp,v 1.6 2005/06/29 15:23:57 orrisroot Exp $ */
 
 #include <windows.h>
 #include <stdio.h>
@@ -552,10 +552,10 @@ static void SetScale(HDC hdc, RECT rect, bm_window_context_t *wcon,
   // font
   hFont = CreateFont(12, 0,0,0,FW_NORMAL,0,0,0,SHIFTJIS_CHARSET,
                      OUT_STROKE_PRECIS,CLIP_DEFAULT_PRECIS,DRAFT_QUALITY,
-                     FIXED_PITCH ,"MS PSVbN");
+                     FIXED_PITCH ,"MS Sans Serif");
   hFont1 = CreateFont(10, 0,0,0,FW_NORMAL,0,0,0,SHIFTJIS_CHARSET,
                      OUT_STROKE_PRECIS,CLIP_DEFAULT_PRECIS,DRAFT_QUALITY,
-                     FIXED_PITCH ,"MS PSVbN");
+                     FIXED_PITCH ,"MS Sans Serif");
   hFontOld = (HFONT)SelectObject(hdc, hFont);
   SetBkMode(hdc, TRANSPARENT);
   // vertical
